@@ -1,3 +1,45 @@
+package Apache::PassFile;
+use Apache::Constants ':common';
+use FileHandle;
+use strict;
+use vars qw($VERSION $BUFFERSIZE);
+$BUFFERSIZE = 16384;
+
+$VERSION = "0.04";
+
+sub BUFFERSIZE {
+  my($self,$new) = @_;
+  $new += 0 if $new;
+  $BUFFERSIZE = $new || $BUFFERSIZE || 16384;
+}
+
+sub handler {
+  my $r = shift;
+  my $filename = $r->filename();
+  my $fh;
+
+  if (-f $filename and
+      -r _ and
+      $fh = FileHandle->new($filename)) {
+    $r->send_http_header;
+    my($buf,$read);
+    local $\;
+
+    while (){
+      defined($read = sysread($fh, $buf, $BUFFERSIZE)) or return SERVER_ERROR;
+      last unless $read;
+      print $buf;
+    }
+    $fh->close;
+    return OK;
+  } else {
+    return NOT_FOUND; 
+  }
+}
+
+1;
+
+__END__
 
 =head1 NAME
 
@@ -14,8 +56,15 @@ In the conf/access.conf file of your Apache installation add lines
 
 =head1 DESCRIPTION
 
-This is an efficient version of cat(1) in perl. While it innocently
-prints to STDOUT it may well be the case that STDOUT has been tied.
+This handler implements nothing but a quite efficient cat(1) in perl.
+While it innocently prints to STDOUT it may well be the case that
+STDOUT has been tied, and that's the only reason why this module is
+needed. Once we can stack any apache modules on top of each other,
+this module becomes obsolete.
+
+PassFile reads files from disk in chunks of size BUFFERSIZE.
+BUFFERSIZE is a global variable that can be set via the BUFFERSIZE
+method. The default value is 16384.
 
 =head1 AUTHOR
 
@@ -25,35 +74,3 @@ Masaryk University, Brno (small performance changes by Andreas Koenig)
 
 =cut
 
-package Apache::PassFile;
-use Apache::Constants ':common';
-use FileHandle;
-use strict;
-use vars qw($VERSION);
-$VERSION = "0.01";
-
-sub handler {
-  my $r = shift;
-  my $filename = $r->filename();
-  my $fh;
-
-  if (-f $filename and
-      -r _ and
-      $fh = FileHandle->new($filename)) {
-    $r->send_http_header;
-    my($buf,$read);
-    local $\;
-
-    while (){
-      defined($read = sysread($fh, $buf, 16384)) or return SERVER_ERROR;
-      last unless $read;
-      print $buf;
-    }
-    $fh->close;
-    return OK;
-  } else {
-    return NOT_FOUND; 
-  }
-}
-
-1;
